ts-backend-check
================

`View code on Github <https://github.com/activist-org/ts-backend-check/tree/main/src/ts_backend_check>`_

.. toctree::
    :maxdepth: 2

    cli/index
    parsers/index
    test_project/index

.. toctree::
    :maxdepth: 1

    checker
    utils
